package com.seitenbau.junit;

import java.lang.reflect.Method;
import java.util.Collection;

/**
 * Core interface for providing Test Data for the DataDrivenTestRunner
 */
public interface IDataTestProvider
{

  /**
   * Initialize the Provider for the current Test
   * 
   * @param testClass The test Class reference
   * 
   * @param testMethod The reference to the Test Method.
   */
  void init(Class<?> testClass, Method testMethod);

  /**
   * Returns a list of the concrete ITestData items.
   * 
   * @return
   * 
   */
  Collection<? extends ITestData> buildTestData();

  /**
   * Provides a post text which appears in the JUnit GUI
   * 
   * @return
   */
  String getDescriptionPostText();

  /**
   * Provides the Test Method for this Test
   * 
   * @return
   */
  Method getTestMethod();

  /**
   * Provides the Test Class
   * 
   * @return
   */
  Class<?> getTestClass();

}
