package com.seitenbau.junit;

import java.lang.reflect.Method;

/**
 * Basic Interface for Listeners on a Data Driven Test
 * 
 * See also
 * @DataDrivenTestListener
 */
public interface IParameterizedTestListener
{

  /**
   * Setup the concrete Listener
   * 
   * @param testClass The Class Object of the test class.
   * 
   * @param testMethod The Test Method the Data Driven Tests are
   *        executed on
   * 
   * @throws Exception Just for convenience
   */
  void init(Class<?> testClass, Method testMethod) throws Exception;

  /**
   * Callback directly after a Test instance for one of the DataDriven
   * Tests has been created.
   * 
   * @param testInstance The just created Instance of the Test
   * 
   * @throws Exception Just for convenience
   */
  void afterCreateTest(Object testInstance) throws Exception;

  /**
   * Callback after one of the DataDriven Tests had been executed.
   * 
   * @throws Exception Just for convenience
   */
  void afterTestExecution() throws Exception;

}
