package com.seitenbau.junit;

import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;

import org.junit.internal.runners.TestClass;
import org.junit.runner.Description;

/**
 * Wrapper for one Data Driven Test.
 * 
 * This interface allows a delegation of the actual invoke from inside
 * the Test Runner to you own implementation.
 */
public interface ITestData
{

  /**
   * @return Get the Description for the JUnit GUI
   */
  Description getDescription();

  /**
   * create the concrete test Instance
   * 
   * @param testClass A JUnit4 TestClass object.
   * @return The new Instance of this class
   */
  Object createTest(TestClass testClass);

  /**
   * Do the actual Invoke of the Test with the given Test instance.
   * 
   * @param testMethod The test method reference the Data Driven Test
   *        should run on. Use this to modify parameter before
   *        invocation.
   * 
   * @param testClassInstance
   * 
   * @throws IllegalArgumentException
   * @throws IllegalAccessException
   * @throws InvocationTargetException
   */
  void invoke(Method testMethod, Object testClassInstance)
      throws IllegalArgumentException, IllegalAccessException,
      InvocationTargetException;

  /**
   * Set the Test Context for this test.
   * 
   * @param testContext
   */
  void setTestContext(ITestContext testContext);

}
